@@ -3,16 +3,28 @@ use crate::random::RandomURLConfig;
 use byte_unit::Byte;
 use config::{self, ConfigError};
 use std::path::{Path, PathBuf};
+use std::time::Duration;
 
 /// Configuration values.
 #[derive(Debug, Clone, Default, serde::Serialize, serde::Deserialize)]
 pub struct Config {
+    /// Configuration settings.
+    #[serde(rename = "config")]
+    pub settings: Option<Settings>,
     /// Server configuration.
     pub server: ServerConfig,
     /// Paste configuration.
     pub paste: PasteConfig,
 }
 
+/// General settings for configuration.
+#[derive(Debug, Clone, Default, serde::Serialize, serde::Deserialize)]
+pub struct Settings {
+    /// Refresh rate of the configuration file.
+    #[serde(with = "humantime_serde")]
+    pub refresh_rate: Duration,
+}
+
 /// Server configuration.
 #[derive(Debug, Clone, Default, serde::Serialize, serde::Deserialize)]
 pub struct ServerConfig {
@@ -24,6 +36,11 @@ pub struct ServerConfig {
     pub max_content_length: Byte,
     /// Storage path.
     pub upload_path: PathBuf,
+    /// Request timeout.
+    #[serde(default, with = "humantime_serde")]
+    pub timeout: Option<Duration>,
+    /// Authentication token.
+    pub auth_token: Option<String>,
 }
 
 /// Paste configuration.
@@ -39,16 +56,28 @@ pub struct PasteConfig {
     pub mime_blacklist: Vec<String>,
     /// Allow duplicate uploads
     pub duplicate_files: Option<bool>,
+    /// Delete expired files.
+    pub delete_expired_files: Option<CleanupConfig>,
+}
+
+/// Cleanup configuration.
+#[derive(Debug, Clone, Default, serde::Serialize, serde::Deserialize)]
+pub struct CleanupConfig {
+    /// Enable cleaning up.
+    pub enabled: bool,
+    /// Interval between clean-ups.
+    #[serde(default, with = "humantime_serde")]
+    pub interval: Duration,
 }
 
 impl Config {
     /// Parses the config file and returns the values.
     pub fn parse(path: &Path) -> Result<Config, ConfigError> {
-        let mut config = config::Config::default();
-        config
-            .merge(config::File::from(path))?
-            .merge(config::Environment::new().separator("__"))?;
-        config.try_into()
+        config::Config::builder()
+            .add_source(config::File::from(path))
+            .add_source(config::Environment::default().separator("__"))
+            .build()?
+            .try_deserialize()
     }
 }
 
